<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => '​ធ្វើ​អោយសកម្ម plugin',
	'affichage' => 'បង្ហាញចេញ',
	'aide_non_disponible' => 'ផ្នែក​នេះ នៃជំនួយ លើអិនរើណែត គ្មានស្រាប់ សំរាប់ភាសានេះ។',
	'auteur' => 'អ្នកនិពន្ធ៖',
	'avis_acces_interdit' => 'ការ​ចូល​ទៅ ត្រូវ​បាន​ហាម។',
	'avis_article_modifie' => 'ប្រយត្ន, @nom_auteur_modif@ )បានធ្វើការ លើអត្ថបទ​នេះ បាន @date_diff@ នាទី',
	'avis_aucun_resultat' => 'គ្មានរកឃើញ​ លទ្ធផល។',
	'avis_chemin_invalide_1' => 'ផ្លូវ អ្នកបានជ្រើសយក',
	'avis_chemin_invalide_2' => 'ប្រហែលគ្មានសុពលភាព។ សូមត្រលប់ទៅ ទំព័រមុន និងផ្ទៀងពត៌មានបានផ្តល់។',
	'avis_connexion_echec_1' => 'បញ្ជាប់ទៅ ខំព្យូរើបំរើសេវា SQL បានបរាជ័យ។',
	'avis_connexion_echec_2' => 'ត្រលប់ទៅ ទំព័រ​មុន និងផ្ទៀងពត៌មាន ​ដែល​អ្នក​បាន​ផ្ដល់​។',
	'avis_connexion_echec_3' => '<b>ចំណាំសំខាន់</b> លើមួយចំនួនខំព្យូរើបំរើសេវា, អ្នកត្រូវតែ <b>ស្នើ</b> ការធ្វើអោយសកម្ម ការចូលទៅ របស់អ្នក ក្នុងមូលដ្ឋានទិន្នន័យ មុនអាចប្រើប្រាស់វា។ បើអ្នកគ្មានអាចភ្ជាប់ទៅ, អ្នកផ្ទៀង តើអ្នកបានអនុវត្ត ការធ្វើអោយសកម្មនេះ។',
	'avis_connexion_ldap_echec_1' => 'បញ្ជាប់ទៅ ខំព្យូរើបំរើសេវា LDAP បានបរាជ័យ។',
	'avis_connexion_ldap_echec_2' => 'ត្រលប់ទៅ ទំព័រមុន, និងផ្ទៀង ពត៌មាន អ្នកបានផ្តល់។',
	'avis_connexion_ldap_echec_3' => 'តាមជំរើស, កុំ​ប្រើ​ប្រាស់ការ​គាំទ្រ LDAP ដើម្បី​នាំចូលអ្នក​ប្រើប្រាស់។', # MODIF
	'avis_deplacement_rubrique' => 'ប្រយត្ន! មាតិកា​នេះ ​មានផ្ទុក @contient_breves@ ពត៌មានសង្ខេប @scb@ ៖ បើ​អ្នក​ប្តូរទីតាំងវា, សូមគូស ប្រអប់បញ្ជាក់ទទួលស្គាល់ នេះ។',
	'avis_erreur_connexion_mysql' => 'កំហុស​ ភ្ជាប់ទៅ SQL ',
	'avis_espace_interdit' => '<b>តំបន់ហាម</b> <div>SPIP ធ្លាប់ត្រូវ​បានតំលើង។</div>',
	'avis_lecture_noms_bases_1' => 'កម្មវិធីតំលើង គ្មាន​អាច ​អាន​ឈ្មោះ​ឃ្លាំង​ទិន្នន័យ​ ដែល​ត្រូវបានតំលើង។',
	'avis_lecture_noms_bases_2' => '​ឃ្លាំង​ទិន្នន័យ គ្មានស្រាប់, ឬមុខងារអនុញ្ញាត ការរាយបញ្ជី​ នុមូលដ្ឋានទិន្នន័យ គ្មានត្រូវបានអនុញ្ញាត ព្រោះហេតុផលសុវត្ថភាព (វាជាករណី ជាមួយច្រើនខំព្យូរើ)។',
	'avis_lecture_noms_bases_3' => 'ករណីជំរើសទីពីរ ពិត, វាអាចជាលទ្ធភាព ដែលមួួមូលដ្ឋានទិន្នន័យ ត្រូវបានដាក់ឈ្មោះ ក្រោយការពិនិត្យចូល របស់អ្នក អាចត្រូវបានប្រើប្រាស់៖',
	'avis_non_acces_page' => 'អ្នក​គ្មានអាច ​ចូល​ទៅ​ ​ទំព័រ​នេះ។',
	'avis_operation_echec' => 'ប្រតិបត្ដិការ ​បានបរាជ័យ។',
	'avis_operation_impossible' => 'ប្រតិបត្ដិការ​ មិន​អាចទៅ​រួច',
	'avis_suppression_base' => 'ប្រយត្ន, ការលុបចេញ​ទិន្នន័យ គ្មានអាច​ត្រលប់​វិញ',

	// B
	'bouton_acces_ldap' => 'បន្ថែម​ ការ​ចូល​ទៅ LDAP ',
	'bouton_ajouter' => 'បន្ថែម',
	'bouton_annuler' => 'បោះបង់',
	'bouton_demande_publication' => 'សួររក ការផ្សព្វផ្សាយ នៃអត្ថបទនេះ',
	'bouton_desactive_tout' => 'អសកម្មទាំងអស់',
	'bouton_desinstaller' => 'លែងតំលើង',
	'bouton_effacer_tout' => 'លុប​ចេញ ទាំងអស់',
	'bouton_envoyer_message' => 'សារ​បញ្ចប់ ៖ ផ្ញើ',
	'bouton_modifier' => 'កែប្រែ',
	'bouton_radio_afficher' => 'បង្ហាញចេញ',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នកតែងនិពន្ធ ​ដែល​បានភ្ជាប់', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'ផ្ញើ​ ការប្រកាសដំណឹង ទៅអាសយដ្ឋាន ៖',
	'bouton_radio_envoi_liste_nouveautes' => 'ផ្ញើ​ ប​ញ្ជី នៃអ្វី ដែលថ្មី',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​ អ្នកតែងនិពន្ធ', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'មិន​ផ្ញើ​ ការប្រកាសដំណឹង ​ដែល​ផ្សព្វផ្សាយ',
	'bouton_redirection' => 'បណ្តូរទិស',
	'bouton_relancer_installation' => 'តំលើង ឡើងវិញ',
	'bouton_suivant' => 'បន្ទាប់',
	'bouton_tenter_recuperation' => 'ព្យាយាម​ជួសជុល',
	'bouton_test_proxy' => 'សាកល្បង ខំព្យូរើបំរើសេវា Proxy',
	'bouton_vider_cache' => 'ពង្រីង សតិភ្ជាប់',

	// C
	'cache_modifiable_webmestre' => 'អាចផ្លាស់ប្តូរ ប៉ារ៉ាម៉ែត្រ​នេះ​ ដោយអ្នកជំនាញវ៉ែប នៃសៃថ៍។', # MODIF
	'calendrier_synchro' => 'បើ​អ្នក​ប្រើ​ប្រាស់ ផ្នែកទន់សៀវភៅកត់ត្រា សមស្រប <b>iCal</b>, អ្នក​អាច សមកាលវា ជាមួយពត៌មាន នៃសៃថ៍នេះ។',
	'config_activer_champs' => 'ធ្វើអោយសកម្ម វាលខាងក្រោម',
	'config_choix_base_sup' => 'ដាក់ឈ្មោះ មូលដ្ឋានទិន្នន័យ លើខំព្យូរើបំរើសេវានេះ',
	'config_erreur_base_sup' => 'SPIP គ្មានអាចចូលទៅ មូលដ្ឋានទិន្នន័យ មានស្រាប់',
	'config_info_enregistree' => 'បានរក្សាទុកហើយ ការកំណត់ទំរង់ថ្មីនេះ',
	'config_info_logos_utiliser' => 'ប្រើប្រាស់ រូបសញ្ញា',
	'config_info_logos_utiliser_non' => 'គ្មានប្រើប្រាស់ រូបសញ្ញា',
	'config_titre_base_sup' => 'ការប្រកាស នៃមួយមូលដ្ឋានទិន្នន័យបន្ថែម',
	'config_titre_base_sup_choix' => 'ជ្រើសរើសបន្ថែម មួយមូលដ្ឋានទិន្នន័យ',
	'connexion_ldap' => 'កា​រ​ភ្ជាប់ ៖',

	// D
	'date_mot_heures' => 'ម៉ោង',

	// E
	'email' => 'អ៊ីមែវល៍',
	'email_2' => 'អ៊ីមែវល៍ ៖',
	'entree_adresse_annuaire' => 'អាសយដ្ឋាន​ នៃបញ្ជី​​ឈ្មោះ',
	'entree_adresse_email' => 'អាសយដ្ឋានអ៊ីមែវល៍ របស់​អ្នក',
	'entree_base_donnee_1' => 'អាសយដ្ឋាន នៃ​ឃ្លាំង​ទិន្នន័យ',
	'entree_base_donnee_2' => '(​ជា​រឿយៗ អា​សយ​ដ្ឋាន​នេះ​ ត្រូវ​តាម ​អាសយដ្ឋាន នៃសៃថ៍ របស់​អ្នក, ជួនកាល ​វា​ត្រូវតាម ការកំណត់ «localhost», ជួនកាល ​វា​នៅ​ទទេ ​ទាំងស្រុង។​)',
	'entree_biographie' => 'ជីវប្រវត្ដិ​ខ្លី​ ត្រឹមប៉ុន្មានពាក្យ។',
	'entree_chemin_acces' => '<b>បញ្ចូល</b> ផ្លូវចូលទៅ៖',
	'entree_cle_pgp' => 'កូនសោ PGP របស់​អ្នក',
	'entree_contenu_rubrique' => 'ខ្លឹមសារ ​នៃ​ផ្នែក​នេះ​ ត្រឹមតែប៉ុន្មានពាក្យ។​)',
	'entree_identifiants_connexion' => 'អត្ដសញ្ញា ​ភ្ជាប់​ របស់​អ្នក​...',
	'entree_informations_connexion_ldap' => 'បំពេញបែបបទ​នេះ ​ពត៌មានបញ្ជាប់ ទៅបញ្ជីឈ្មោះ LDAP របស់អ្នក។ 
​ពត៌មាន​តាំងនេះ ត្រូវតែអាចផ្តល់ទៅអ្នក ​តាមអ្នកអភិបាល នៃប្រព័ន្ធ, 
 ឬ នៃបណ្តាញ។', # MODIF
	'entree_infos_perso' => 'អ្នកជា អ្នកណា?',
	'entree_interieur_rubrique' => 'ពី​ក្នុង​ផ្នែក ៖',
	'entree_liens_sites' => '<b>តំណភ្ជាប់ អត្ថបទខ្ពស់</b> (​ឯកសារយោង សៃថ៍​ សំរាប់ចូលមើល...)',
	'entree_login' => 'ការ​ពិនិត្យចូល​ របស់​អ្នក',
	'entree_login_connexion_1' => 'ការ​ពិនិត្យចូល ដើម្បី​ភ្ជាប់',
	'entree_login_connexion_2' => '(​ជួនកាល ត្រូវតាម ​ការពិនិត្យ​ចូល​ ទៅ FTP របស់​អ្នក, ជួនកាល ទុកនៅទទេ​)',
	'entree_mot_passe' => 'ពាក្យសំងាត់ ​របស់​អ្នក',
	'entree_mot_passe_1' => 'ពាក្យសំងាត់ សំរាប់ភ្ជាប់',
	'entree_mot_passe_2' => '(​ជួនកាល ​ត្រូវតាម ពាក្យសំងាត់ របស់អ្នក សំរាប់ FTP, ​ជួនកាល ទុកនៅទទេ)',
	'entree_nom_fichier' => 'សូមបញ្ចូល ​ឈ្មោះ​សំណុំឯកសារ @texte_compresse@៖',
	'entree_nom_pseudo' => 'ឈ្មោះ របស់អ្នក ឬ ​ឈ្មោះ​ហៅ​ក្រៅ​ របស់​អ្នក',
	'entree_nom_pseudo_1' => '(​ឈ្មោះ របស់អ្នក ឬ ​ឈ្មោះ​ហៅ​ក្រៅ​ របស់​អ្នក​)',
	'entree_nom_site' => 'ឈ្មោះសៃថ៍ របស់​អ្នក',
	'entree_nouveau_passe' => 'ពាក្យសំងាត់ថ្មី',
	'entree_passe_ldap' => 'ពាក្យសំងាត់',
	'entree_port_annuaire' => 'លេខ​ច្រក​ នៃ​បញ្ជី​​ឈ្មោះ',
	'entree_signature' => 'ហត្ថលេខា',
	'entree_titre_obligatoire' => '<b>ចំណងជើង</b> [តំរូវ​ អោយ​មាន]<br />',
	'entree_url' => 'អាសយដ្ឋាន URL នៃសៃថ៍ របស់អ្នក',
	'erreur_plugin_fichier_absent' => 'សំណុំឯកសារ អវត្តមាន',
	'erreur_plugin_fichier_def_absent' => 'អវត្តមាន សំណុំឯកសារនិយម​ន័យ',
	'erreur_plugin_nom_fonction_interdit' => 'ឈ្មោះ​មុខងារ ត្រូវ​បាន​ហាម',
	'erreur_plugin_nom_manquant' => 'ខ្វះឈ្មោះ​កម្មវិធី​ជំនួយ',
	'erreur_plugin_prefix_manquant' => 'គ្មានបានកំណត់ វាលដាក់ឈ្មោះ​ នៃកម្មវិធី​ជំនួយ​',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; ខ្វះ ​ក្នុងសំណុំឯកសារ​និយម​ន័យ',
	'erreur_plugin_version_manquant' => 'ខ្វះកំណែ​ នៃ​កម្មវិធី​ជំនួយ',

	// I
	'ical_info1' => 'ទំព័រ​នេះ​ បង្ហាញ​ ច្រើន​វិធី ​ដើម្បី​ទាក់ទង ជានិច្ច ​ជាមួយជីវិត នៃសៃថ៍នេះ។',
	'ical_info2' => 'សំរាប់ពត៌មាន​បន្ថែម លើគ្រប់បច្ចេកទេស, សូមកុំ​ស្ទាក់ស្ទើរ​ ​ចូលមើល <a href="@spipnet@">កំរងឯកសារ SPIP</a>។',
	'ical_info_calendrier' => 'ពីប្រក្រតីទិន មានស្រាប់ សំរាប់អ្នក។ ទី​មួយ ជា​ផែនទី​ នៃសៃថ៍ ប្រកាសអំពី គ្រប់អត្ថបទ ត្រូវបានផ្សព្វផ្សាយ។ ទី​ពីរ ​មានផ្ទុក ការប្រកាសដំណឹង ផ្សព្វផ្សាយក៏ដូច​ជា សារ​ឯកជនថ្មីៗ របស់​អ្នក៖
វា​បង្ការ សំរាប់អ្នក ដោយសារតែ មួយកូនសោផ្ទាល់ខ្លួន, ដែលអ្នកអាច កែប្រែ នៅគ្រប់ពេល ដោយធ្វើថ្មីឡើងវិញ ពាក្យសំងាត់ របស់អ្នក។',
	'ical_methode_http' => 'ទំនាញយក',
	'ical_methode_webcal' => 'ភាពសមកាល (webcal://)', # MODIF
	'ical_texte_prive' => 'ប្រក្រតីទិន, ប្រើប្រាស់ត្រឹមផ្ទាល់ខ្លួន, ផ្តល់ពត៌មាន អ្នក អំពីសកម្មភាពបោះផ្សាយឯកជន នៃសៃថ៍នេះ (ភារៈកិច្ច និង ការណាត់ជួបផ្ទាល់ខ្លួន, អត្ថបទ និង ពត៌មានខ្លី ត្រូវបានស្នើ...)។',
	'ical_texte_public' => 'ប្រក្រតីទិននេះ អនុញ្ញាតអ្នក តាមដាន សកម្មភាពសាធារណៈ នៃសៃថ៍នេះ (អត្ថបទ និង ពត៌មានខ្លី ត្រូវបានបោះផ្សាយ)។',
	'ical_texte_rss' => 'អ្នកអាចបញ្ជាប់ ពត៌មានថ្មីៗ នៃសៃថ៍នេះ ក្នុង រាល់ប្រអប់អានឯកសារ ជាទំរង់ XML/RSS (សង្ខេបសៃថ៍ សំបូរ)។ វា ក៏ជាទំរង់ អនុញ្ញាត SPIP អានបត៌មានថ្មី បានបោះផ្សាយ លើសៃថ៍ដទៃ ដោយប្រើប្រាស់ មួយទំរង់ផ្លាស់ប្តូរគ្នា។',
	'ical_titre_js' => 'អត្ថបទJava script               ',
	'ical_titre_mailing' => 'បញ្ជី​ការ​ផ្ញើ​មែ​ល',
	'ical_titre_rss' => 'ហ្វា​ល​រួម​បញ្ចូល​គ្នា',
	'icone_activer_cookie' => 'ដាក់​ខូ​គី',
	'icone_admin_plugin' => 'រៀបចំ​កម្មវិធី​ជំនួយ',
	'icone_afficher_auteurs' => 'បង្ហាញ អ្នកនិពន្ធ',
	'icone_afficher_visiteurs' => 'បង្ហាញ​ ពួកអ្នកចូលមើល',
	'icone_arret_discussion' => 'ឈប់​ចូលរួម​ក្នុង​ការ​ពិភាក្សា​នេះ',
	'icone_calendrier' => 'ប្រក្រតីទិន',
	'icone_creer_auteur' => 'បង្កើត​ មួយអ្នកនិពន្ធ​ថ្មី និង​ភ្ជាប់​គាត់ ទៅ​អត្ថបទ​នេះ',
	'icone_creer_mot_cle' => 'បង្កើតថ្មី មួយពាក្យគន្លឹះ និងតភ្ជាប់វា ទៅអត្ថបទនេះ',
	'icone_creer_rubrique_2' => 'បង្កើត មួយផ្នែកថ្មី',
	'icone_modifier_article' => 'កែប្រែ អត្ថបទនេះ',
	'icone_modifier_rubrique' => 'កែប្រែ ផ្នែកនេះ',
	'icone_retour' => 'ត្រលប់ក្រោយ',
	'icone_retour_article' => 'ត្រលប់ ទៅអត្ថបទ',
	'icone_supprimer_cookie' => 'លប់​ខូ​គី',
	'icone_supprimer_rubrique' => 'លុបចេញ ផ្នែកនេះ',
	'icone_supprimer_signature' => 'លប់​ហត្ថលេខា​នេះ',
	'icone_valider_signature' => 'ធ្វើ​អោយ​ហត្ថលេខា​នេះ​មាន​សុពលភាព',
	'image_administrer_rubrique' => 'អ្នក​អាច​គ្រប់គ្រង​ផ្នែក​នេះ',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => 'អត្ថបទ ១',
	'info_activer_cookie' => 'អ្នអ្នក អាចធ្វើអោយសកម្ម មួយ <b>ខូកឃីឆ្លងឆ្លើយ</b>, វា នឹងអនុញ្ញាតអ្នក ងាយដើរ ពីសៃថ៍សាធារណះ ទៅសៃថ៍ឯកជន។',
	'info_administrateur' => 'អ្នកគ្រប់គ្រង', # MODIF
	'info_administrateur_1' => 'អ្នកគ្រប់គ្រង', # MODIF
	'info_administrateur_2' => 'នៃសៃថ៍ (<i>ប្រើប្រាស់ ដោយប្រយត្ន</i>)',
	'info_administrateur_site_01' => 'បើអ្នក ជាអ្នកអភិបាលសៃថ៍, សូម', # MODIF
	'info_administrateur_site_02' => 'ចុចលើ តំណភ្ជាប់នេះ',
	'info_administrateurs' => 'អ្នកគ្រប់គ្រង', # MODIF
	'info_administrer_rubrique' => 'អ្នក​អាច​ចាត់ចែង​ផ្នែក​នេះ',
	'info_adresse' => 'ទៅ​នឹង​អាសយដ្ឋាន ៖',
	'info_adresse_url' => 'អាសយដ្ឋាន URL នៃសៃថ៍សាធារណះ',
	'info_aide_en_ligne' => 'ជំនួយ លើបណ្តាញ SPIP',
	'info_ajout_image' => 'នៅ​ពេល​អ្នក​បន្ថែម​រូប​ជា​ឯកសារ​ភ្ជាប់​ទៅ​នឹង​អត្ថបទ នោះ SPIP អាច​បង្កើត​រូបថត​ដោយ​ស្វ័យប្រវត្ដិ (​គំនូស​ព្រាង​) ពី​រូប​ដែល​បាន​បញ្ចូល ។ ប្រការ​នេះ​នឹង​អនុញ្ញាត ឧទាហរណ៍ អោយ​មានការ​បង្កើត​ដោយ​ស្វ័យប្រវត្ដិ​នូវ​វិចិត្រសាល ឬ​ផលប័ត្រ ។',
	'info_ajouter_rubrique' => 'បន្ថែម​ផ្នែក​មួយទៀត​ដើម្បី​ចាត់ចែង ៖',
	'info_annonce_nouveautes' => 'ជំនូនដំណឹង ចុងក្រោយបំផុត',
	'info_article' => 'អត្ថបទ',
	'info_article_2' => 'អត្ថបទ',
	'info_article_a_paraitre' => 'អត្ថបទ​ចាស់​ដែល​ត្រូវ​បោះ​ពុ​ម្ភ​ផ្សាយ',
	'info_articles_02' => 'អត្ថបទ',
	'info_articles_2' => 'អត្ថបទ',
	'info_articles_auteur' => 'អត្ថបទ របស់អ្នកនិពន្ធនេះ',
	'info_articles_trouves' => 'អត្ថបទ​ត្រូវ​បាន​រក​ឃើញ',
	'info_attente_validation' => 'អត្ថបទ របស់អ្នក កំពុងរង់ចាំ សុពលភាព',
	'info_aujourdhui' => 'ថ្ងៃនេះ ៖',
	'info_auteurs' => 'អ្នកនិពន្ធ',
	'info_auteurs_par_tri' => 'អ្នកនិពន្ធ@partri@',
	'info_auteurs_trouves' => 'អ្នកនិពន្ធ​ត្រូវ​បាន​រក​ឃើញ',
	'info_authentification_externe' => 'យថាភាព​ខាងក្រៅ',
	'info_avertissement' => 'ការ​ព្រមាន',
	'info_barre_outils' => 'ជាមួយ របារឧបករ របស់វា ឬ?',
	'info_base_installee' => 'បានតំលើង រចនាសម្ពន្ធ មូលដ្ឋានទិន្នន័យ របស់អ្នក។',
	'info_chapeau' => 'ឧបករ រក្សា​ទិន្នន័យ',
	'info_chapeau_2' => 'សេចក្ដី​ផ្ដើម ៖',
	'info_chemin_acces_1' => 'ជម្រើស ៖<b>ច្រកចូល​នៅ​ក្នុង​បញ្ជី​រាយ​ឈ្មោះ</b>',
	'info_chemin_acces_2' => 'ពីពេលនេះ, អ្នកត្រូវតែកំណត់ទំរង់ ផ្លូវចូលទៅ ពត៌មាននៃថតឯកសារ។ ពត៌មាននេះ មានខ្លឹមសារសំខាន់ សំរាប់អាន ពត៌មានផ្ទាល់ខ្លួន របស់អ្នកប្រើប្រាស់ បានតំកល់ទុក ក្នុងថតឯកសារ។', # MODIF
	'info_chemin_acces_annuaire' => 'ជម្រើស ៖<b>ច្រកចូល​នៅ​ក្នុង​បញ្ជី​រាយ​ឈ្មោះ</b>',
	'info_choix_base' => 'ជំហាន​ទី​បី ៖',
	'info_classement_1' => ' out of @liste@',
	'info_classement_2' => ' out of @liste@',
	'info_code_acces' => 'កុំភ្លេច អក្សរកូដចូលទៅ ផ្ទាល់ខ្លួន របស់អ្នក!',
	'info_config_suivi' => 'បើអាសយដ្ឋាននេះ ត្រូវតាម បញ្ជីផ្ញើមែវល៍, អ្នក អាចបង្ហាញខាងក្រោម អាសយដ្ឋាន ដែលពួកអ្នកចូលរួម សៃថ៍ អាចចុះឈ្មោះ។ អាសយដ្ឋាននេះ អាចជា មួយអាសយដ្ឋាន URL (ជា ឧទាហរ ទំព័រចុះឈ្មោះ ទៅបញ្ជី​តាមរយះវ៉ែប), ឬ អាសយដ្ឋានអ៊ីមែវល៍ បានមានប្រធានបទ ជាក់លាក់ (ជា ឧទាហរ៖ <tt>@adresse_suivi@?subject=subscribe</tt>)៖',
	'info_config_suivi_explication' => 'អ្នក អាចជាវប្រចាំ ទៅបញ្ជីផ្ញើមែវល៍ នៃសៃថ៍នេះ។ អ្នក នឹងទទួលបាន តាមមែវល៍ រាល់ជំនូនដំណឹង នៃអត្ថបទ​និង​នៃពត៌មានខ្លី បានស្នើ សំរាប់ការបោះផ្សាយ។',
	'info_confirmer_passe' => 'បញ្ជាក់ទទួលស្គាល់ ពាក្យសំងាត់ថ្មី៖',
	'info_conflit_edition_differences' => 'ភាពខុសគ្នា៖',
	'info_conflit_edition_version_enregistree' => 'បានរក្សាទុក កំណែ៖',
	'info_conflit_edition_votre_version' => 'កំណែ របស់អ្នក៖',
	'info_connexion_base' => 'ជំហាន​ ​ពីរ ៖<b>ព្យាយាម ​ភ្ជាប់​ទៅ​ ឃ្លាំង​ទិន្នន័យ</b>',
	'info_connexion_base_donnee' => 'ការភ្ជាប់ទៅ មូលដ្ឋានទិន្នន័យ របស់អ្នក',
	'info_connexion_ldap_ok' => 'កា​រត​ភ្ជាប់ LDAP របស់​អ្នក​បាន​សម្រេច​ជោគជ័យ</b><p> អ្នក​អាច​ទៅ​កាន់​ជំហាន​បន្ទាប់​បាន ។</p>', # MODIF
	'info_connexion_mysql' => 'ជំហាន​ទី​មួយ ៖ <b>កា​រត​ភ្ជាប់ MySQL របស់​អ្នក</b>',
	'info_connexion_ok' => 'កា​រត​ភ្ជាប់​បាន​សម្រេច​ជោគជ័យ ។',
	'info_contact' => 'ទំនាក់ទំនង',
	'info_contenu_articles' => 'ខ្លឹមសារ​អត្ថបទ',
	'info_creation_paragraphe' => '(​ដើម្បី​បង្កើត​កថាខណ្ឌ អ្នក​គ្រាន់តែ​ទុក​អោយ​មាន​បន្ទាត់​ទទេរ ។​)', # MODIF
	'info_creation_rubrique' => 'មុន​ពេល​អាច​សរសេរ​អត្ថបទ<br /> អ្នក​ត្រូវ​តែ​បង្កើត​យ៉ាង​ហោច​ណាស់​មួយ​ផ្នែក ។<br />',
	'info_creation_tables' => 'ជំហាន​ទី​បួន ៖ <b>ការ​បង្កើត​តារាង​ឃ្លាំង​ទិន្នន័យ</b>',
	'info_creer_base' => '<b>បង្កើត</b> ឃ្លាំង​ទិន្នន័យ​ថ្មី',
	'info_dans_rubrique' => 'ក្នុង​ផ្នែក ៖',
	'info_date_publication_anterieure' => 'កាលបរិច្ឆេទ​នៃ​ការ​បោះ​ពុ​ម្ភ​ផ្សាយ​កាលពី​លើក​មុន ៖',
	'info_date_referencement' => 'ថ្ងៃខែឆ្នាំ នៃការយោង របស់សៃថ៍នេះ ៖ ',
	'info_derniere_etape' => 'ជំហាន​ចុង​ក្រោយ ៖  រួចរាល់​!',
	'info_descriptif' => 'ការពិពណ៌នា៖',
	'info_desinstaller_plugin' => 'លុបចេញ ទិន្នន័យ និងធ្វើអោយអសកម្ម plugin',
	'info_discussion_cours' => 'ការពិភាក្សា កំពុងដំណើរ',
	'info_ecrire_article' => 'មុន​ពេល​អាច​សរសេរ​អត្ថបទ​បាន អ្នក​ត្រូវ​បង្កើត​យ៉ាង​ហោច​ណាស់​មួយ​ផ្នែក ។',
	'info_email_envoi' => 'អាសយដ្ឋានអ៊ីមែវល៍ របស់ម្ចាស់បញ្ញើ (ជាជំរើស)',
	'info_email_envoi_txt' => 'បញ្ចូល អាយដ្ឋានអ៊ីមែវល៍ របស់អ្នកផ្ញើ ធ្លាប់បានប្រើប្រាស់ ពេលផ្ញើអ៊ីមែវល៍ (ជាលំនាំដើម, អាសយដ្ឋានអ្នកទទួល ត្រូវបានប្រើប្រាស់ ជាអាសយដ្ឋានអ្នកផ្ញើ) ៖',
	'info_email_webmestre' => 'អាសយដ្ឋានអ៊ីមែវល៍ របស់អ្នកជំនាញវ៉ែប (ជាជំរើស)', # MODIF
	'info_envoi_email_automatique' => 'ការ​ផ្ញើ​មែ​ល​ដោយ​ស្វ័យប្រវត្ដិ',
	'info_envoyer_maintenant' => 'ផ្ញើ ឥឡូវ',
	'info_etape_suivante' => 'ទៅ ជំហានបន្ទាប់',
	'info_etape_suivante_1' => 'អ្នកអាចទៅ ជំហានបន្ទាប់។',
	'info_etape_suivante_2' => 'អ្នកអាចទៅ ជំហានបន្ទាប់។',
	'info_exportation_base' => 'នាំចេញ មូលដ្ឋានទិន្នន័យ ទៅ @archive@',
	'info_facilite_suivi_activite' => 'សំរាប់សំរួល ការតាមដាន សកម្មភាពបោះផ្សាយ នៃសៃថ៍, SPIP អាចជូនដំណឹង តាមមែវល៍, ជាឧទាហរ ទៅបញ្ជីផ្ញើមែវល៍ របស់ពួកស្មេរ, ជំនូនដំណឹង នៃសំណើ បោះផ្សាយនានា និងភាពសុពលភាព នៃអត្ថបទនានា។', # MODIF
	'info_fichiers_authent' => 'ហ្វា​ល​យថាភាព \\".htpasswd\\"',
	'info_forums_abo_invites' => 'វ៉ែបសៃថ៍ របស់អ្នក រួមមាន ទីប្រជុំមតិ តាមរយះការជាវ ; ចឹង ពួកទស្សនាករ អាចចុះឈ្មោះ ចូលរួម ទីប្រជុំមតិទាំងនេះ លើសៃថ៍សាធារណះ។', # MODIF
	'info_gauche_admin_tech' => '<b>ត្រឹម ពួកអ្នកទទួលខុសត្រូវសៃថ៍ អាចចូលទៅ ទំព័រនេះ។</b><p> វាអនុញ្ញាត អោយចូលទៅ មុខងារថែទាំបច្ចេកទេស ដទៃ។ មួយចំនួននៃមុខងារ ផ្តល់ដំណើរ សំគាល់ជាក់លាក់, តំរូវអោយមាន FTP សំរាប់ចូលទៅ វ៉ែបសៃថ៍។</p>', # MODIF
	'info_gauche_auteurs' => 'អ្នកនឹងឃើញ ទីនេះ គ្រប់អ្នកនិពន្ធ នៃវ៉ែបសៃថ៍។
 ស្ថានភាព របស់ពួកគេ ត្រូវបានសំគាល់ ដោយ ពណ៌នៃរូបតំណាង (អ្នកអភិបាល = បៃតង; អ្នកបោះផ្សាយ = លឿង;)', # MODIF
	'info_gauche_auteurs_exterieurs' => 'ពួកអ្នកនិពន្ធ ពីខាងក្រៅ, គ្មានអាចចូលទៅ វ៉ែបសៃថ៍, ត្រូវបានសំគាល់ ជារូបតំណាង ពណ៌ខៀវ ;
​ ពួកអ្នកនិពន្ធ ត្រូវបានលុបចេញ ដោយធុងសំរាម។', # MODIF
	'info_gauche_messagerie' => 'ការ​ផ្ញើ​សារ​អនុញ្ញាត​អោយ​អ្នក​ផ្លាស់​ប្ដូរ​សារ​ក្នុង​ចំណោម​បណ្ណាធិកា ដើម្បី​រក្សា​ទុក​អនុស្សរណៈ  (​សម្រាប់​ការ​ប្រើប្រាស់​ផ្ទាល់ខ្លួន​របស់​អ្នក​) ឬ​ដើម្បី​បង្ហាញ​នូវ​សេចក្ដី​ប្រកាស​នៅ​លើ​គេហទំព័រ​នៃ​កន្លែង​ឯកជន (​ប្រសិនបើ​អ្នក​គឺជា​អ្នកគ្រប់គ្រង​) ។', # MODIF
	'info_gauche_statistiques_referers' => 'ទំព័រនេះ បង្ហាញ បញ្ជី<i>ឯកសារយោង</i>, បានន័យថា វ៉ែបសៃថ៍ មានផ្ទុកតំណភ្ជាប់ សំដៅសៃថ៍ផ្ទាល់ របស់អ្នក, ត្រឹម ម្សិល និងថ្ងៃនេះ ; បញ្ជីនេះ ត្រូវបានត្រលប់ទៅ សូន្យ រាល់ ២៤ ម៉ោង។',
	'info_gauche_visiteurs_enregistres' => 'អ្នកនឹង រកឃើញ ទីនេះ ពួកទស្សនាករ
 ក្នុងធ្លាសាធារណះ នៃវ៉ែបសៃថ៍ (​ទីប្រជុំមតិ ជាវប្រចាំ)។',
	'info_generation_miniatures_images' => 'បង្កើត​គំនូស​ព្រាង​រូបភាព',
	'info_hebergeur_desactiver_envoi_email' => '“​កុំព្យូទ័រ​ខ្លះ​បិទមុខ​ងារ​ផ្ញើ​សារ​ស្វ័យប្រវត្ដិ',
	'info_hier' => 'ម្សិល​ម៉ិ​ញៈ',
	'info_identification_publique' => 'អត្តសញ្ញា សាធារណះ របស់អ្នក...',
	'info_image_process' => 'ជ្រើសយក វិធីប្រពៃបំផុត សំរាប់បង្កើត កូនរូបភាព ដោយ ចុចលើ រូបភាពទាក់ទិន។',
	'info_image_process2' => '<b>ចំណាំ៖</b> <i>បើគ្មានរូបភាព លេចឡើង, ពេលខំព្យូរើបំរើសេវា ដែលទទួលផ្ទុកវ៉ែបសៃថ៍ របស់អ្នក គ្មានត្រូវបានកំណត់ទំរង់ សំរាប់ប្រើប្រាស់ ឧបករបែបចឹង។ បើអ្នក ចង់ប្រើប្រាស់ មុខងារទាំងនេះ, ទាក់ទងអ្នកទទួលខុសត្រូវ ផ្នែកបច្ចេកទេស និងសួរ ផ្នែកបន្ថែម «GD» ឬ «Imagick»</i>', # MODIF
	'info_images_auto' => 'រូបភាព​ដែល​ត្រូវ​បាន​រាប់​ដោយ​ស្វ័យប្រវត្ដិ',
	'info_informations_personnelles' => 'ជំហាន​ទី​ប្រាំ ៖ <b>Personal information</b>',
	'info_inscription_automatique' => 'ការចុះឈ្មោះស្វ័យប្រវត្តិ ពួកស្មេរថ្មី', # MODIF
	'info_jeu_caractere' => 'កញ្ចប់ភាសា នៃសៃថ៍',
	'info_jours' => 'ថ្ងៃ',
	'info_laisser_champs_vides' => 'ទុក​ប្រអប់​នេះ​ទំនេរ',
	'info_langues' => 'ភាសា នៃសៃថ៍',
	'info_ldap_ok' => 'LDAP បញ្ជាក់​ភាព​ត្រឹមត្រូវ ត្រូវ​បាន​ដំឡើង​។',
	'info_lien_hypertexte' => 'តំណភ្ជាប់ អត្ថបទខ្ពស់៖',
	'info_liste_redacteurs_connectes' => 'បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​ទាក់ទង', # MODIF
	'info_login_existant' => 'ការពិនិត្យចូលនេះ មានស្រាប់ហើយ។',
	'info_login_trop_court' => 'ការពិនិត្យចូល ខ្លីពេក។',
	'info_logos' => 'រូបសញ្ញា',
	'info_maximum' => 'អតិបរមាៈ',
	'info_meme_rubrique' => 'នៅ​ក្នុង​ផ្នែក​ដដែល',
	'info_message_en_redaction' => 'សារ​របស់​លោក​អ្នក​កំពុង​ដំណើរការ',
	'info_message_technique' => 'សារ​បច្ចេកទេសៈ',
	'info_messagerie_interne' => 'ការ​បញ្ជូន​សារ​ខាងក្នុង',
	'info_mise_a_niveau_base' => 'ការ​កែ​លំអ​សំណុំ​ទិន្នន័យMySQL ',
	'info_mise_a_niveau_base_2' => '{{ប្រយត្ន!}} អ្នក បានតំលើង មួយកំណែ
 ឯកសារ SPIP (ចាស់)ជាង កំណែត្រូវបានតំលើង លើសៃថ៍នេះ៖ មូលដ្ឋានទិន្នន័យ របស់អ្នក អាចនឹងត្រូវបានបាត់ និងសៃថ៍ របស់អ្នក នឹងលែងធ្វើការ។ <br />{{តំលើងឡើងវិញ ឯកសារ SPIP។}}',
	'info_modifier_auteur' => 'កែប្រែ ភាពលំអិតនៃអ្នកនិពន្ធ៖',
	'info_modifier_rubrique' => 'កែប្រែ ផ្នែក៖',
	'info_modifier_titre' => 'កែប្រែ៖ @titre@',
	'info_mon_site_spip' => 'សៃថ៍ SPIP របស់ខ្ញុំ',
	'info_moyenne' => 'មធ្យមៈ',
	'info_multi_cet_article' => 'ភាសា​ក្នុង​អត្ថបទ​នេះ',
	'info_multi_langues_choisies' => 'សូមជ្រើសយក ភាសាមានស្រាប់ ខាងក្រោម សំរាប់ ពួកស្មេរ នៃសៃថ៍ របស់អ្នក។
ភាសា ត្រូវបានប្រើប្រាស់ហើយ ក្នុងសៃថ៍ របស់អ្នក(បង្ហាញ ដំបូង) គ្មានអាចត្រូវបាន អសកម្ម។', # MODIF
	'info_multi_secteurs' => '...​សំរាប់​តែ​ផ្នែក​ដែល​នៅ​ខាងក្រោម​គេ​ប៉ុណ្ណោះ​?',
	'info_nom' => 'ឈ្មោះ',
	'info_nom_destinataire' => 'ឈ្មោះ​អ្នក​ទទួល',
	'info_nom_site' => 'ឈ្មោះវ៉ែបសៃថ៍ របស់ខ្ញុំ',
	'info_nombre_articles' => 'អត្ថបទ',
	'info_nombre_rubriques' => 'ផ្នែក',
	'info_nombre_sites' => '@nb_sites@ វ៉ែបសៃថ៍,',
	'info_non_deplacer' => 'សូមកុំ​រំកិល',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP អាចផ្ញើទៀងទាត់ ជំនូនដំណឹង ពត៌មានថ្មីៗ ចុងក្រោយ នៃវ៉ែបសៃថ៍
 (អត្ថបទ និងពត៌មានខ្លី ត្រូវបានបោះផ្សាយថ្មីៗ។',
	'info_non_envoi_liste_nouveautes' => 'កុំផ្ញើ បញ្ជីដំណឹងចុងក្រោយបំផុត',
	'info_non_modifiable' => 'គ្មានអាចត្រូវបាន កែប្រែ',
	'info_non_suppression_mot_cle' => 'ខ្ញុំ គ្មានចង់លុបចេញ ពាក្យគន្លឹះនេះ។',
	'info_notes' => 'កំណត់សំគាល់​នៅ​ចុង​ទំព័រ',
	'info_nouvel_article' => 'អត្ថបទ​ថ្មី',
	'info_nouvelle_traduction' => 'អត្ថបទ​បកប្រែ​ថ្មីៈ',
	'info_numero_article' => 'លេខ​អត្ថបទៈ',
	'info_obligatoire_02' => '[ចាំបាច់]', # MODIF
	'info_option_accepter_visiteurs' => 'យល់ព្រម ការចុះឈ្មោះ ពួកទស្សនាករ នៃវ៉ែបសៃថ៍​សាធារណះ', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'បដិសេធ ការចុះឈ្មោះ របស់ទស្សនាករ', # MODIF
	'info_options_avancees' => 'ជំរើស​ពិសេស',
	'info_ou' => 'ឬ​....',
	'info_page_interdite' => 'ទំព័រ​ហាមឃាត់',
	'info_par_nom' => 'តាម​ឈ្មោះ',
	'info_par_nombre_article' => 'តាម​ចំនួន​អត្ថបទ',
	'info_par_statut' => 'តាម​ស្ថានភាព',
	'info_par_tri' => '’(by @tri@)’',
	'info_passe_trop_court' => 'ពាក្យសំងាត់ ខ្លីពេក។',
	'info_passes_identiques' => 'ពាក្យសំងាត់ ទាំងពីរ គ្មានដូចគ្នា។',
	'info_plus_cinq_car' => 'លើសពី​ ៥ អក្សរ',
	'info_plus_cinq_car_2' => '(​លើស​ពី ៥ អក្សរ​)',
	'info_plus_trois_car' => '(​លើស​ពី ៣ អក្សរ​)',
	'info_popularite' => 'ភាពពេញនិយម៖ ៖ @popularite@; ចំណូលមើល៖ @visites@',
	'info_post_scriptum' => 'បដ្ឋនាលិខិត',
	'info_post_scriptum_2' => 'បដ្ឋនាលិខិត',
	'info_pour' => 'សំរាប់',
	'info_preview_texte' => 'គ្មានអាចមើលមុន សៃថ៍ ដូចដែលគ្រប់អត្ថបទ និងខ្ទង់ដំណឹង (ដែលមានយ៉ាងតិច ស្ថានភាព "បានដាក់ស្នើ") ត្រូវបានបោះផ្សាយហើយ។ បែបមើលមុននេះ គួរត្រូវបានអនុញ្ញាត សំរាប់ពួកអ្នកអភិបាល, បើក សំរាប់គ្រប់អ្នកនិពន្ធ, ឬ គ្មានអនុញ្ញាតទាំងស្រុង?', # MODIF
	'info_procedez_par_etape' => 'សូម​ដំណើរការ​មួយ​ជំហាន​ម្ដងៗ',
	'info_procedure_maj_version' => 'គួរ​បើក​ដំណើរការ​នីតិវិធី​កែ​លំអ​ដើម្បី​សម្រួល​ដល់​ការ​ប្រើប្រាស់​ទិន្នន័យ​ទៅ​ក្នុង​វើ​សឹ​ន (version) របស់ SPIP',
	'info_proxy_ok' => 'ការ​ពិនិត្យ​លើ​វើ​សឹ​ន​ថ្មី​ទទួល​បាន​ជោគជ័យ​។',
	'info_ps' => 'បញ្ជាក់(P.S)',
	'info_publier' => 'ចុះ​ផ្សាយ',
	'info_publies' => 'រាល់អត្ថបទ របស់អ្នក ត្រូវបានបោះផ្សាយ លើអិនរើណែត',
	'info_question_accepter_visiteurs' => 'ប្រសិនបើ​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​អនុញ្ញាត​ឱ្យ​អ្នក​ទស្សនា​ចុះ​ឈ្មោះ​ដោយ​មិន​ចាំបាច់​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន សូម​បើកមុខ​ងារ​ជំរើស​ខាងក្រោមៈ', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'តើ​លោក​អ្នក​ត្រូវការ​អនុញ្ញាត​ឱ្យ​អ្នក​សរសេរ​អត្ថបទ​ថ្មី​ចុះ​ឈ្មោះ​ពី​វ៉ិ​ប​សាយ​សាធារណៈ​ដែល​ឬទេ​? ប្រសិនបើ​លោក​អ្នក​យល់ព្រម អ្នក​ទស្សនា​នឹង​អាច​ចុះ​ឈ្មោះ​ដោយ​ប្រើប្រាស់​ទម្រង់​ស្វ័យប្រវត្ដិ​មួយ ហើយ​បន្ទាប់​មក​ចូល​ក្នុង​ផ្នែក​ឯកជន​ដើម្បី​បញ្ចូល​អត្ថបទ​ផ្ទា់ល់​របស់​ពួក​គេ​។ <blockquote> ក្នុង​ពេល​ដំណើរការ​ចុះ​ឈ្មោះ អ្នក​ប្រើប្រាស់​ទទួល​បាន​អ៊ី​ម៉ែ​ល​ស្វ័យប្រវត្ដិ​ដែល​ផ្ដល់​ជូន​ពួក​គេ​នូវ​លេខ​កូដ​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន​។ ក្រុមហ៊ុន​ផ្ដល់​សេវា​មួយ​ចំនួន​មិន​អនុញ្ញាត​ចំពោះ​ការ​ផ្ញើ​អ៊ី​ម៉ែ​ល​ម៉ាស៊ីន​មេ (servers)​របស់​ពួក​គេ​ទេ ៖ ក្នុង​ករណី​នោះ ការ​ចុះ​ឈ្មោះ​ដោយ​ស្វ័យប្រវត្ដិ​គឺ​មិន​អាច​អនុវត្ដ​បាន​ទេ​។', # MODIF
	'info_racine_site' => 'ឫស នៃវ៉ែបសៃថ៍',
	'info_recharger_page' => 'សូម​បញ្ចូល​ទំព័រ​នេះ​ជា​ថ្មី​ម្ដងទៀត​នៅ​មួយសន្ទុះ​ក្រោយ',
	'info_recherche_auteur_zero' => 'គ្មាន​លទ្ធផល​ទេ​សំរាប់ \\"@cherche_auteur@\\".',
	'info_recommencer' => 'សូម​ព្យាយាម​ម្ដងទៀត',
	'info_redacteur_1' => 'Rédacteur',
	'info_redacteur_2' => 'បាន​ចូល​មក​ដល់​ផ្នែក​ឯកជន (<i>recommended</i>)',
	'info_redacteurs' => 'អ្នក​សរសេរ​អត្ថបទ',
	'info_redaction_en_cours' => 'កំពុង តែងអត្ថបទ',
	'info_redirection' => 'ការ​កំណត់​ទិស​ដៅ​ជា​ថ្មី',
	'info_refuses' => 'អត្ថបទ របស់អ្នក ត្រូវបានបដិសេធ',
	'info_reglage_ldap' => 'ជម្រើសៈ<b>Adjusting LDAP import</b>',
	'info_renvoi_article' => '<b>Redirection.</b> អត្ថបទ​នេះ​ត្រូវ​ប្ដូរ​ទិស​ដៅ​ជា​ថ្មី​ទៅៈ',
	'info_reserve_admin' => 'ត្រឹម ពួកអ្នកអភិបាល អាចកែប្រែ អាសយដ្ឋាននេះ។', # MODIF
	'info_restreindre_rubrique' => 'កំណត់​ការ​គ្រប់គ្រង​ត្រឹមតែ​ចំពោះ​ផ្នែកៈ',
	'info_resultat_recherche' => 'លទ្ធផល​នៃ​ការ​ស្វែងរកៈ',
	'info_rubriques' => 'ផ្នែក',
	'info_rubriques_02' => 'ផ្នែក',
	'info_rubriques_trouvees' => 'ផ្នែក ត្រូវបានរកឃើញ',
	'info_sans_titre' => 'គ្មាន​ចំណងជើង',
	'info_selection_chemin_acces' => '<b>ជ្រើសយក</b> ខាងក្រោម ​ផ្លូវចូល​ទៅ​បញ្ជីឈ្មោះ ៖',
	'info_signatures' => 'ហត្ថលេខា',
	'info_site' => 'សៃថ៍',
	'info_site_2' => 'សៃថ៍៖',
	'info_site_min' => 'សៃថ៍',
	'info_site_reference_2' => 'សៃថ៍​យោង',
	'info_site_web' => 'វ៉ែប​​សៃថ៍ ៖', # MODIF
	'info_sites' => '​​សៃថ៍',
	'info_sites_lies_mot' => '​​សៃថ៍យោង​ ដែល​មាន​ពាក្យ​គន្លឹះ​នេះ',
	'info_sites_proxy' => '​ប្រើប្រាស់​ មួយខំព្យូរើបំរើសេវា Proxy',
	'info_sites_trouves' => 'បានរកឃើញ សៃថ៍',
	'info_sous_titre' => 'ចំណងជើង​រង៖',
	'info_statut_administrateur' => 'អ្នកអភិបាល', # MODIF
	'info_statut_auteur' => 'ស្ថានភាព នៃអ្នកនិពន្ធ នេះ៖',
	'info_statut_auteur_a_confirmer' => 'ការ​ចុះ​ឈ្មោះ​ ដែល​ត្រូវ​បញ្ជាក់ទទួលស្គាល់',
	'info_statut_auteur_autre' => 'ស្ថានភាព ដទៃ ៖',
	'info_statut_redacteur' => 'អ្នក​តែងនិពន្ធ',
	'info_statut_utilisateurs_1' => 'ស្ថានភាព​ លំនាំដើម នៃអ្នក​ប្រើប្រាស់​ ដែល​បានត្រូវនាំចូល', # MODIF
	'info_statut_utilisateurs_2' => 'ជ្រើសរើស​ស្ថានភាព​ដែល​បញ្ជាក់​អំពី​បុគ្គល​ដែល​មាននៅ​ក្នុង​បញ្ជី (directory) LDAP នៅ​ពេល​ដែល​ពួក​គេ​ភ្ជាប់​ជា​លើក​ដំបូង​។ ក្រោយមក​លោក​អ្នក​អាច​កែសម្រួល​តម្លៃ​នេះ​សំរាប់​អ្នក​សរសេរ​កម្មវិធី​នីមួយៗ ដោយ​ផ្នែក​លើ​ករណី​មួយៗ​។', # MODIF
	'info_suivi_activite' => 'ការតាមដាន សកម្មភាពបោះផ្សាយ',
	'info_surtitre' => 'ចំណងជើងកំពូល៖',
	'info_syndication_integrale_1' => 'វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​ផ្ដល់​នូវ​ហ្វា​ល (file) បញ្ចូល(see <a href=\\"@url@\\">@titre@</a>)។',
	'info_syndication_integrale_2' => 'អ្នកមានសំណូមពរ ផ្ញើ អត្ថបទទាំងមូល ឬ ត្រឹមមួយសង្ខេប នៃរាប់រយអក្សរ ឬ?',
	'info_taille_maximale_vignette' => 'ទំហំ​អតិបរមា​នៃ​ម៉ូត​រចនា​ដែល​បង្កើត​ឡើង​ដោយ​ប្រព័ន្ធ ៖',
	'info_terminer_installation' => 'អ្នក បច្ចុប្បន្ន អាចបញ្ចប់ ដំណើរតំលើង លំនាំដើម។',
	'info_texte' => 'អត្ថបទ',
	'info_texte_explicatif' => 'អត្ថបទ​ពន្យល់',
	'info_texte_long' => '(​ឯ​កសារ​វែងៈ វា​បង្ហាញ​ជា​ច្រើន​ផ្នែក​ដែល​នឹង​រួម​បញ្ចូល​គ្នា​បន្ទាប់​ពី​មាន​សុពលភាព​។​)',
	'info_texte_message' => 'អត្ថបទ នៃសារ របស់អ្នក៖', # MODIF
	'info_texte_message_02' => 'អត្ថបទ​សារ',
	'info_titre' => 'ចំណងជើង៖',
	'info_total' => 'សរុបៈ',
	'info_tous_articles_en_redaction' => 'គ្រប់អត្ថបទ ក្នុងដំណើរសរសេរ',
	'info_tous_articles_presents' => 'គ្រប់អត្ថបទ ត្រូវបានបោះផ្សាយ ក្នុងផ្នែកនេះ',
	'info_tous_les' => 'រាល់៖',
	'info_tout_site' => 'សៃថ៍ ទាំងមូល',
	'info_tout_site2' => 'អត្ថបទ គ្មានទាន់ត្រូវបាន ប្រែសំរួល ជាភាសានេះ។',
	'info_tout_site3' => 'អត្ថបទ ត្រូវបានប្រែសំរួល ជាភាសានេះ, ប៉ុន្តែ​មានបំលាស់ប្តូរ បន្ទាប់ពីអត្ថបទយោង។ បំរែសំរួល ត្រូវការ ការបន្ទាន់សម័យ។ ',
	'info_tout_site4' => 'អត្ថបទ ត្រូវបានប្រែសំរួល ជាភាសានេះ, និង បំរែសំរួល ត្រូវបានបន្ទាន់សម័យ។',
	'info_tout_site5' => 'អត្ថបទដើម៖',
	'info_tout_site6' => '<b>ប្រយត្ន៖</b> ត្រឹមអត្ថបទដើម ត្រូវបានបង្ហាញ.
 បំរែសំរួល ត្រូវបានផ្សារជាប់ ទៅអត្ថបទ,
 ដោយមានមួយពណ៌ បង្ហាញស្ថានភាព របស់វា ៖',
	'info_travail_colaboratif' => 'ការងារ​រួម​សំរាប់​អត្ថបទ',
	'info_un_article' => 'អត្ថបទ',
	'info_un_site' => 'មួយសៃថ៍,',
	'info_une_rubrique' => 'ផ្នែក',
	'info_une_rubrique_02' => 'មួយ​ផ្នែក',
	'info_url' => 'URL ​៖',
	'info_urlref' => 'តំណភ្ជាប់ខ្ពស់ ៖',
	'info_utilisation_spip' => 'ពេលនេះ អ្នកអាចផ្តើមប្រើប្រាស់ SPIP មានការណែនាំ....',
	'info_visites_par_mois' => 'ការ​បង្ហាញ​ចេញ ប្រចាំខែ ៖',
	'info_visiteur_1' => 'ទស្សនាករ',
	'info_visiteur_2' => 'នៃសៃថ៍​សាធារណៈ',
	'info_visiteurs' => 'ទស្សនាករ',
	'info_visiteurs_02' => '​ទស្សនាករ នៃសៃថ៍​សាធារណៈ',
	'install_echec_annonce' => 'ការ​តំលើង​នេះ ​អាច​នឹងបរាជ័យ, ឬ​ អាចនាំ​ទៅ មួយសៃថ៍ខូច...',
	'install_extension_mbstring' => 'SPIP គ្មានធ្វើការ ​ជាមួយ ៖',
	'install_extension_php_obligatoire' => 'SPIP ទាមទារ កន្ទុយ .php ៖',
	'install_pas_table' => 'មូលដ្ឋានទិន្នន័យ គ្មានទាន់មានតារាង',
	'install_php_version' => 'កំណែ PHP @version@ មិនគ្រប់សមត្ថភាព (​យ៉ាងអន់ = @minimum@))',
	'install_select_langue' => 'ជ្រើសយក មួយ​ភាសា រួច​ចុចលើប្រអប់ « បន្ទាប់ » ដើម្បី​ផ្ដើម ដំណើរតំលើង។',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_tables_base' => 'ពួកតារាង នៃមូលដ្ឋានទិន្នន័យ',
	'install_types_db_connus' => 'SPIP អាចប្រើប្រាស់ <b>MySQL</b> (ញឹកញាប់បំផុត), <b>PostgreSQL</b> និង <b>SQLite</b>.', # MODIF
	'intem_redacteur' => 'អ្នកតែងនិពន្ធ',
	'intitule_licence' => 'អាជ្ញាបណ្ណ',
	'item_accepter_inscriptions' => 'ព្រមទទួល ការ​ចុះ​ឈ្មោះទាំងឡាយ',
	'item_activer_messages_avertissement' => 'សកម្ម សារព្រមាន',
	'item_administrateur_2' => 'អ្នកអភិបាល', # MODIF
	'item_afficher_calendrier' => 'បង្ហាញ​ចេញ ក្នុង​ប្រក្រតីទិន',
	'item_autoriser_syndication_integrale' => 'បញ្ចូល​អត្ថបទ​ទាំងមូល​ទៅ​ក្នុង​ហ្វា​ល (files) បញ្ចូល​។',
	'item_choix_administrateurs' => 'អ្នកគ្រប់គ្រង​ប្រព័ន្ធ', # MODIF
	'item_choix_generation_miniature' => 'បង្កើត​ទម្រង់​រូបភាព​សង្ខេប​ច្បាស់ៗ​ដោយ​ស្វ័យប្រវត្ដិ',
	'item_choix_non_generation_miniature' => 'មិន​បង្កើត​ទម្រង់​រូបភាព​សង្ខេប​ច្បាស់',
	'item_choix_redacteurs' => 'អ្នក​សរសេរ​អត្ថបទ',
	'item_choix_visiteurs' => 'ពួកទស្សនាករ នៃសៃថ៍សាធារណះ',
	'item_creer_fichiers_authent' => 'បង្កើត​ហ្វា​ល (files).htpasswd',
	'item_login' => 'ការពិនិត្យចូល',
	'item_mots_cles_association_articles' => 'អត្ថបទ',
	'item_mots_cles_association_rubriques' => 'ផ្នែក',
	'item_mots_cles_association_sites' => 'ទៅ សៃថ៍ត្រូវបានយោង ឬ ត្រូវបានបានភ្ជាប់។',
	'item_non' => 'ទេ',
	'item_non_accepter_inscriptions' => 'មិន​អនុញ្ញាត​ចំពោះ​ការ​ចុះ​ឈ្មោះ',
	'item_non_activer_messages_avertissement' => 'គ្មាន​សារ​រំលឹក',
	'item_non_afficher_calendrier' => 'គ្មានបង្ហាញ ក្នុងប្រក្រតីទិន',
	'item_non_autoriser_syndication_integrale' => 'គ្រាន់តែ​ផ្ញើ​សេចក្ដី​សង្ខេប',
	'item_non_creer_fichiers_authent' => 'មិន​បង្កើត​ឯកសារ​ទាំងនេះ',
	'item_non_publier_articles' => 'មិន​ចុះ​ផ្សាយ​អត្ថបទ​មុន​កាលបរិច្ឆេទ​ចុះ​ផ្សាយ​របស់​វា',
	'item_nouvel_auteur' => 'អ្នក​សរសេរ​កម្មវិធី​ថ្មី',
	'item_nouvelle_rubrique' => 'ផ្នែក​ថ្មី',
	'item_oui' => 'បាទ​,​ចាស',
	'item_publier_articles' => 'បោះពុម្ព​អត្ថបទ​ដោយ​មិន​គិត​អំពី​កាលបរិច្ឆេទ​បោះពុម្ព​របស់​វា',
	'item_reponse_article' => 'ចំលើយ ទៅអត្ថបទ',
	'item_visiteur' => 'ទស្សនាករ',

	// J
	'jour_non_connu_nc' => 'គ្មានស្គាល់',

	// L
	'lien_ajouter_auteur' => 'បន្ថែម​អ្នក​សរសេរ​កម្មវិធី​នេះ',
	'lien_email' => 'អ៊ី​ម៉ែ​ល',
	'lien_nom_site' => 'ឈ្មោះសៃថ៍៖',
	'lien_retirer_auteur' => 'ដកចេញ អ្នកនិពន្ធនេះ',
	'lien_site' => 'សៃថ៍',
	'lien_tout_deplier' => 'ពង្រីក​ ទាំងអស់',
	'lien_tout_replier' => 'រួម​បញ្ចូល​គ្នា​ទាំងអស់',
	'lien_tout_supprimer' => 'លុបចេញ ទាំងអស់',
	'lien_trier_nom' => 'ដាក់​ជា​ក្រុម​ទៅ​តាម​ឈ្មោះ',
	'lien_trier_nombre_articles' => 'ដាក់​ជា​ក្រុម​ទៅ​តាម​ចំនួន​អត្ថបទ',
	'lien_trier_statut' => 'ដាក់​ជា​ក្រុម​ទៅ​តាម​ស្ថានភាព',
	'lien_voir_en_ligne' => 'មើល លើអិនរើណែត៖',
	'logo_article' => 'ឡូ​ហ្គោ​របស់​អត្ថបទ', # MODIF
	'logo_auteur' => 'ឡូ​ហ្គោ​របស់​អ្នក​សរសេរ​កម្មវិធី', # MODIF
	'logo_rubrique' => 'រូបសញ្ញា នៃផ្នែក', # MODIF
	'logo_site' => 'រូបសញ្ញា នៃសៃថ៍នេះ', # MODIF
	'logo_standard_rubrique' => 'រូបសញ្ញាគំរូ របស់ផ្នែក', # MODIF
	'logo_survol' => 'ឡូ​ហ្គោ​សំកាំង', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'ការ​ជ្រើសរើស​សំណុំ​ទិន្នន័យ​របស់​លោក​អ្នក',
	'module_fichier_langue' => 'ហ្វា​ល​ភាសា',
	'module_raccourci' => 'ផ្លូវ​កាត់',
	'module_texte_affiche' => 'អត្ថបទ ត្រូវបានបង្ហាញចេញ',
	'module_texte_explicatif' => 'លោក​អ្នក​អាច​បញ្ចូល​ផ្លូវ​កាត់​ខាងក្រោម​នេះ​ទៅ​ក្នុង​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​។ ផ្លូវការ​ទាំងនេះ​នឹង​ត្រូវ​បកប្រែ​ដោយ​ស្វ័យប្រវត្ដិ​ទៅ​ជា​ភាសា​ផ្សេងៗ​ដែល​មាននៅ​ក្នុង​ហ្វា​ល​ភាសា​។',
	'module_texte_traduction' => 'ហ្វា​ល​ភាសារ « @module@ » មាននៅ​ក្នុងៈ',
	'mois_non_connu' => 'គ្មានបានស្គាល់',

	// O
	'onglet_contenu' => 'ខ្លឹមសារ',
	'onglet_declarer_une_autre_base' => 'ប្រកាស មួយមូលដ្ឋានទិន្នន័យ ដទៃ',
	'onglet_discuter' => 'ពិភាក្សា',
	'onglet_proprietes' => 'លក្ខណះ',
	'onglet_repartition_actuelle' => 'ឥឡូវ',
	'onglet_sous_rubriques' => 'ផ្នែករង',

	// P
	'plugin_erreur_charger' => 'កំហុស៖ គ្មានអាចផ្ទុក @zip@',
	'plugin_etat_developpement' => 'ក្នុងដំណើរ អភិវឌ្ឍ',
	'plugin_etat_experimental' => 'ដែល​ពិសោធន៍',
	'plugin_etat_stable' => 'នឹង',
	'plugin_etat_test' => 'ដែល​ត្រូវ​បាន​ពិសោធ',
	'plugin_impossible_activer' => 'គ្មានអាចធ្វើអោយសកម្ម plugin  @plugin@',
	'plugin_info_automatique2' => 'បង្កើត មួយថតឯកសារ <code>@rep@</code> ;',
	'plugins_liste' => 'បញ្ជី​កម្មវិធី​ជំនួយ',
	'protocole_ldap' => 'វឺ​សឹ​ន (version) ពិធីការ',

	// R
	'repertoire_plugins' => 'បញ្ជី (directory)',
	'required' => '[ចាំបាច់]', # MODIF

	// S
	'statut_admin_restreint' => '(​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ​ដែល​ត្រូវ​ហាមឃាត់​)', # MODIF

	// T
	'taille_cache_image' => 'រូបភាព ត្រូវបានគណនា ស្វ័យប្រវត្តិ ដោយ SPIP (​ទំរង់សង្ខេប ឯកសារ, ចំណងជើង ត្រូវបានបង្ហាញ ជាក្រាភិក, អនុគមគណិត ជាទំរង់ TeX) មានសរុប @taille@ ​ក្នុង​ថតឯកសារ @dir@ ។',
	'taille_cache_octets' => 'ទំហំ​ថត​លាក់ខ្លួន​គឺ @octets@ ថ្មីៗ​។', # MODIF
	'taille_cache_vide' => 'ថត​លាក់ខ្លួន​ទទេ​។',
	'taille_repertoire_cache' => 'ទំហំ​បច្ចុប្បន្ន​នៃ​ថត​លាក់ខ្លួន​។',
	'text_article_propose_publication' => 'អត្ថបទ ត្រូវបានស្នើបោះផ្សាយ។',
	'texte_acces_ldap_anonyme_1' => 'ម៉ាស៊ីន​មេLDAP មួយ​ចំនួន​មិន​អនុញ្ញាត​ចំពោះ​ការ​ប្រើប្រាស់​ជា​លក្ខណៈ​អនាមិក​នោះ​ទេ​។ នៅ​ក្នុង​ករណី​នេះ លោក​អ្នក​ត្រូវ​បង្ហាញ​នូវ​អ្នក​កំណត់​អត្ដសញ្ញាណ​ក្នុង​ការ​ប្រើប្រាស់​ដំបូង ដើម្បី​អាច​ស្វែងរក​ព័ត៌មាន​នៅ​ក្នុង​ថត (directory) បន្ទាប់​ពី​នោះ​។ ប៉ុន្ដែ នៅ​ក្នុង​ករណី​ភាគច្រើន​ក្រឡោ​ន​ខាងក្រោម​នេះ​អាច​ទុក​ចំហ​ដដែល​។',
	'texte_admin_effacer_01' => 'បញ្ជា​នេះ​លុប <i>all</i> ខ្លឹមសារ​នៃ​សំណុំ​ទិន្នន័យ រាប់​បញ្ចូល​ទាំង <i>all</i> លក្ខណៈ​តម្រូវ​សំរាប់​ការ​ប្រើប្រាស់​របស់​អ្នក​សរសេរ​អត្ថបទ និង​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ​។ បន្ទាប់​ពី​ប្រើប្រាស់​វា លោក​អ្នក​ត្រូវ​តំឡើង SPIP ជា​ថ្មី ដើម្បី​បង្កើត​ទិន្នន័យ​ថ្មី និង​ការ​ប្រើប្រាស់​អ្នកគ្រប់គ្រង​លើក​ទី​មួយ​ម្ដងទៀត​។', # MODIF
	'texte_adresse_annuaire_1' => '(​ប្រសិនបើ​ថត​របស់​លោក​អ្នក​ត្រូវ​បាន​តំឡើង​នៅ​ក្នុង​ម៉ាស៊ីន​តែ​មួយ​ដូច​គ្នា​នឹង​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក វា​អាច «localhost»)',
	'texte_ajout_auteur' => 'អ្នក​សរសេរ​កម្មវិធី​ខាងក្រោម​ត្រូវ​បាន​បញ្ចូល​ទៅ​ក្នុង​អត្ថបទៈ',
	'texte_annuaire_ldap_1' => 'ប្រសិនបើ​លោក​អ្នក​អាច​ប្រើប្រាស់​ថត (directory) (LDAP) លោក​អ្នក​អាច​ប្រើប្រាស់​វា​ដើម្បី​បញ្ចូល​អ្នក​ប្រើប្រាស់​ក្រោម SPIP ដោយ​ស្វ័យប្រវត្ដិ​។', # MODIF
	'texte_article_statut' => 'ស្ថានភាព​អត្ថបទ',
	'texte_article_virtuel' => 'អត្ថបទ​ជាក់ស្ដែង',
	'texte_article_virtuel_reference' => '<b>Virtual article:</b> អត្ថបទ​យោង​នៅ​ក្នុង​វ៉ិ​ប​សាយ SPIP របស់​លោក​អ្នក ប៉ុន្ដែ​ត្រូវ​កំណត់​ទិស​ដៅ​ថ្មី​ទៅ​កាន់ URL មួយ​ផ្សេង​ទៀត​។ ដើម្បី​លុប​ការ​កំណត់​ទិស​ដៅ​ជា​ថ្មី​នេះ សូម​លុបURL ខាងលើ​។',
	'texte_aucun_resultat_auteur' => 'គ្មាន​លទ្ធផល​សំរាប់ \\"@cherche_auteur@\\"។',
	'texte_auteur_messagerie' => 'វ៉ិ​ប​សាយ​នេះ​អាច​តាមដាន​ជា​បន្ដបន្ទាប់​នូវ​បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​បាន​ភ្ជាប់ ដែល​អនុញ្ញាត​ឱ្យ​លោក​អ្នក​ដោះ​ដូរ​សារ​តាម​ពេល​ជាក់ស្ដែង​។ លោក​អ្នក​អាច​សំរេច​មិន​បង្ហាញខ្លួន​នៅ​ក្នុង​បញ្ជី​នេះ (​ដូច្នេះ​លោក​អ្នក​ស្ថិត​ក្នុង​សភាព “​មើល​មិនឃើញ​” (\\"invisible\\") សំរាប់​អ្នក​ប្រើប្រាស់​ផ្សេង​ទៀត​។​)', # MODIF
	'texte_auteurs' => 'អ្នក​សរសេរ​កម្មវិធី',
	'texte_choix_base_1' => 'ជ្រើសយក មូលដ្ឋានទិន្នន័យ របស់អ្នក៖',
	'texte_choix_base_2' => 'ម៉ាស៊ីន​មេMySQL មាន​សំណុំ​ទិន្នន័យ​ច្រើន​។',
	'texte_choix_base_3' => '<b>ជ្រើសយក</b> ខាងក្រោម អ្វីដែល ខំព្យូរើផ្ទុកវ៉ែបសៃថ៍ របស់អ្នក​ បានផ្គត់ផ្គង់ អ្នក៖',
	'texte_compte_element' => 'សមាសធាតុ',
	'texte_compte_elements' => 'សមាសធាតុ',
	'texte_connexion_mysql' => 'ពិនិត្យពត៌មាន បានផ្តល់ដោយ ក្រុមហ៊ុនផ្តល់សេវា របស់អ្នក។ វាប្រហែលមានផ្ទុក អក្សរកូដភ្ជាប់ សំរាប់ខំព្យូរើបំរើសេវា SQL។',
	'texte_contenu_article' => '(​ខ្លឹមសារ​អត្ថបទ​ដោយ​សង្ខេប​)',
	'texte_contenu_articles' => 'ដោយ​ផ្អែក​លើ​ទម្រង់​ដែល​ជ្រើសរើស​សំរាប់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក លោក​អ្នក​អាច​សំរេច​ថា​ធាតុ​នៃ​អត្ថបទ​ខ្លះ​មិន​ត្រូវ​បាន​ប្រើ​។ សូម​ប្រើ​បញ្ជី​ខាងក្រោម​ដើម្បី​ជ្រើសរើស​ធាតុ​ដែល​គួរ​មាន​។',
	'texte_crash_base' => 'បើមូលដ្ឋានទិន្នន័យ របស់អ្នក បានខូច, អ្នកអាចព្យាយាម ជួសជុលវា ស្វ័យប្រវត្តិ។',
	'texte_creer_rubrique' => 'មុនអាចសរសេរ អត្ថបទ<br /> អ្នកត្រូវតែបង្កើត មួយផ្នែក។',
	'texte_date_creation_article' => 'កាលបរិច្ឆេទ​បង្កើត​អត្ថបទៈ',
	'texte_date_publication_anterieure' => 'កាលបរិច្ឆេទ​បោះពុម្ព​មុនគេៈ',
	'texte_date_publication_anterieure_nonaffichee' => 'លាក់​កាលបរិច្ឆេទ​ការ​បោះពុម្ព​មុនគេ',
	'texte_date_publication_article' => 'ថ្ងៃខែឆ្នាំ បោះផ្សាយ លើអិនរើណែត ៖',
	'texte_descriptif_rapide' => 'ការពិពណ៌នារហ័ស',
	'texte_effacer_base' => 'លុបសំអាត មូលដ្ឋានទិន្នន័យ SPIP',
	'texte_effacer_statistiques' => 'លុបចេញ ស្ថិតិ',
	'texte_en_cours_validation' => 'អត្ថបទ និងពត៌មានខ្លី ខាងក្រោម ត្រូវបានស្នើ បោះផ្សាយ។', # MODIF
	'texte_enrichir_mise_a_jour' => 'លោក​អ្នក​អាច​កែ​លំអ​ទម្រង់​អត្ថបទ​របស់​លោក​អ្នក ដោយ​ប្រើប្រាស់ «typographical shortcuts».',
	'texte_fichier_authent' => '<b>តើ SPIP គួរ​បង្កើត <tt>.htpasswd</tt> និង​ហ្វា​ល<tt>.htpasswd-admin</tt> នៅ​ក្នុង​ថត @dossier@?</b><p> ហ្វា​ល​ទាំងនេះ​អាច​ត្រូវ​បាន​ប្រើប្រាស់​ដើម្បី​កំណត់​ចំពោះ​ការ​ប្រើប្រាស់​របស់​អ្នក​សរសេរ​កម្មវិធី និង​អ្នក​គ្រង់​គ្រង​នៅ​ក្នុង​ផ្នែក​មួយ​ផ្សេង​ទៀត​នៃ​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក (​ឧទាហរណ៍ កម្មវិធី​ស្ថិតិ​ខាងក្រៅ​)​។</p><p> ប្រសិនបើ​លោក​អ្នក​មិន​ត្រូវការ​ហ្វា​ល​បែប​នេះ លោក​អ្នក​អាច​ទុក​ជម្រើស​នៅ​ក្នុង​តម្លៃ​ដើម (​គ្មាន​ការ​បង្កើត​ហ្វា​ល​)​។</p>', # MODIF
	'texte_informations_personnelles_1' => 'ប្រព័ន្ធ​នឹង​ផ្ដល់​ជូន​លោក​អ្នក​នូវ​លទ្ធភាព​ប្រើប្រាស់​ធម្មតា​នូវ​វ៉ិ​ប​សាយ​នេះ​។',
	'texte_informations_personnelles_2' => '(ចំណាំ៖ បើវាជា មួយការតំលើងឡើងវិញ, និងការចូលទៅ របស់អ្នក នៅតែធ្វើការ, អ្នកអាច', # MODIF
	'texte_introductif_article' => '(​អត្ថបទ​សេចក្ដី​ផ្ដើម​នៃ​អត្ថបទ​នេះ)',
	'texte_jeu_caractere' => 'លោក​អ្នក​គួរតែ​ប្រើប្រាស់​អក្ខរាវិរុទ្ធ​សកល',
	'texte_jeu_caractere_3' => 'សៃថ៍ របស់អ្នក បច្ចុប្បន្ន ប្រើប្រាស់កញ្ចប់អក្សរនេះ ៖',
	'texte_jeu_caractere_4' => 'ប្រសិនបើ​មិន​អាច​ឆ្លើយ​តប​ចំពោះ​ស្ថានភាព​ដែល​លោក​អ្នកមាន​ជាមួយ​នឹ​ឹ​ង​ទិន្នន័យ​របស់​លោក​អ្នក (​ឧទាហរណ៍ បន្ទាប់​ពី​សើរើ​សំណុំ​ទិន្ន​ន័៏​យ​ពី​ហ្វា​ល​ថត​ទុក​) ឬ​ប្រសិនបើ <em>លោក​អ្នក​កំពុង​កំណត់​វ៉ិ​ប​សាយ​នេះ</em> និង​ត្រូវការ​ប្រើប្រាស់​សំណុំ​តួអក្សរ​ផ្សេង សូម​បង្ហាញ​សំណុំ​តួអក្សរ​នៅ​ទី​នេះៈ',
	'texte_login_ldap_1' => '(​ត្រូវ​ទុក​ប្រអប់​ភ្ជាប់​អនាមិក ឬ​ចូល​ទៅ​ផ្លូវ​ពេញលេញ ឧទាហរណ៍ «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>»)​។',
	'texte_login_precaution' => 'ប្រយត្ន៖ នេះជាការពិនិត្យចូល ជាមួយអ្វី ដែលអ្នកបានភ្ជាប់ ពេលនេះ។ ប្រើប្រាស់ បែបបទនេះ ដោយប្រយត្ន...',
	'texte_mise_a_niveau_base_1' => 'លោក​អ្នក​ទើបតែ​បាន​កែសម្រួល​ហ្វា​លSPIP។ ឥឡូវ​លោក​អ្នក​ត្រូវ​តែ​កែ​លំអ​សំណុំ​ទិន្នន័យ​របស់​វ៉ិ​ប​សាយ​នេះ',
	'texte_modifier_article' => 'កែប្រែ អត្ថបទ៖',
	'texte_multilinguisme' => 'ប្រសិនបើ​លោក​អ្នកមាន​បំណង​គ្រប់គ្រង​អត្ថបទ​ជា​ភាសា​ច្រើន ដែល​មានដំណើរ​ការ​ស្មុគស្មាញ លោក​អ្នក​អាច​បន្ថែម​បញ្ជី​ភាសា​មួយ​ទៅ​ក្នុង​អត្ថបទ និង​/​ឬ​ផ្នែក ទៅ​តាម​ការ​រៀបចំ​នៃ​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​។', # MODIF
	'texte_multilinguisme_trad' => 'លោក​អ្នក​ក៏​អាច​បើកមុខ​ងារ​ប្រព័ន្ធ​គ្រប់គ្រង​ទំនាក់ទំនង​ក្នុង​ចំណោម​អត្ថបទ​បកប្រែ​ជា​ច្រើន​ភាសា​។', # MODIF
	'texte_non_compresse' => '<i>uncompressed</i> (​ម៉ាស៊ីន​មេ​របស់​លោក​អ្នក​មិន​ប្រើប្រាស់​ជាមួយនឹង​លក្ខណៈ​នេះ​ទេ​)',
	'texte_nouvelle_version_spip_1' => 'អ្នក ​បានតំលើង កំណែថ្មី នៃ SPIP។',
	'texte_nouvelle_version_spip_2' => 'វើ​សឹ​ន​ថ្មី​នេះ​តម្រូវ​ឱ្យ​មានការ​កែសម្រួល​លំអិត​ជា​ការ​កែសម្រួល​ធម្មតា​។ ប្រសើ​ន​បើ​លោក​អ្នក​គឺជា​អ្នក​រចនា​វ៉ិ​ប​សាយ​នេះ សូម​លុប​ហ្វា​ល @connect@ និង​ចាប់ផ្ដើម​តំឡើង​ដើម្បី​អាច​កែសម្រួល​លក្ខណៈ​ទំនាក់ទំនង​សំណុំ​ទិន្នន័យ​របស់​លោក​អ្នក​។ <p>(NB.: ប្រសិនបើ​លោក​អ្នក​បាន​ភ្លើ​ច​លក្ខណៈ​ទំនាក់ទំនង​របស់​លោក​អ្នក សូម​មើល​ក្នុង​ហ្វា​ល@ មុន​នឹង​លុប​វា​!)</p>', # MODIF
	'texte_operation_echec' => 'ត្រលប់ទៅ ទំព័រមុន, ជ្រើសយក មួយមូលដ្ឋានទិន្នន័យដទៃ ឬបង្កើតមួយថ្មី។ ផ្ទៀងពត៌មាន ផ្តល់ដោយ ខំព្យូរើ របស់អ្នក។',
	'texte_plus_trois_car' => 'លើស​ពី ៣ អក្សរ',
	'texte_plusieurs_articles' => 'ឃើញ​មាន​អ្នក​សរសេរ​កម្មវិធី​សំរាប់ \\"@cherche_auteur@\\":',
	'texte_port_annuaire' => '(​តម្លៃ​ដើម​ជា​ទូទៅ​មាន​លក្ខណៈ​ថេរ​)​។',
	'texte_presente_plugin' => 'ទំព័រ​នេះ​រាយ​អំពី​កម្មវិធី​បន្ថែម​ដែល​មាននៅ​ក្នុង​វ៉ិ​ប​សាយ​។ បើកមុខ​ងារ​របស់​កម្មវិធី​បន្ថែម លោក​អ្នក​ត្រូវ​គូស​ក្នុង​ប្រអប់​ដែល​ត្រូវ​គ្នា​នោះ​។',
	'texte_proposer_publication' => 'នៅ​ពេល​ដែល​អត្ថបទ​លោក​អ្នក​ត្រូវ​បាន​បញ្ចប់br /> លោក​អ្នក​អាច​បញ្ជូន​វា​ដើម្បី​ចុះ​ផ្សាយ​។',
	'texte_proxy' => 'នៅ​ក្នុង​ករណី​ខ្លះ (​អ៊ី​ន​ត្រា​ណិ​ត បណ្ដាញ​ដែល​ត្រូវ​ការពារ​......) វា​ជា​ការ​ចាំបាច់​ដែល​ត្រូវ​ប្រើប្រាស់ <i>proxy HTTP</i> ដើម្បី​បើក​វ៉ិ​ប​សាយ​ដែល​បាន​បញ្ចូល​។ ប្រសិនបើ​មាន​តំណាង​មួយ សូម​បញ្ចូល​អាសយដ្ឋាន​របស់​វា​ខាងក្រោម ដូច្នេះ <tt><html>http://proxy:8080</html></tt>។ ជា​ទូទៅ លោក​អ្នក​អាច​ទុក​ប្រអប់​នេះ​ឱ្យ​នៅ​ទំនេរ​បាន​។',
	'texte_publication_articles_post_dates' => 'តើ​ឥរិយាបថ​មួយ​ណា​ដែល SPIP ត្រូវ​ប្រើ ទាក់ទិន​ទៅ​នឹង​អត្ថបទ​ដែល​កំណត់​សំរាប់​ការ​ចុះ​ផ្សាយ​នៅ​អនាគត​?',
	'texte_rappel_selection_champs' => '[ចាំ​ថា ត្រូវ​ជ្រើសរើស​ប្រអប់​នេះ​ឱ្យ​បាន​ត្រឹមត្រូវ​។]',
	'texte_recalcul_page' => 'ប្រសិនបើ​លោក​អ្នក​ត្រូវការ​សម្រួល​ឡើង​វិ​ញុ (refresh) តែ​មួយ​ទំព័រ លោក​អ្នក​ត្រូវធ្វើ​វា​ពី​ផ្នែក​សាធារណៈ និង​ប្រើប្រាស់​ប៊ូ​តុង « refresh ».',
	'texte_recuperer_base' => 'ជួសជុល​សំណុំ​ទិន្នន័យ',
	'texte_reference_mais_redirige' => 'អត្ថបទ​យោង​នៅ​ក្នុង​វ៉ិ​ប​សាយSPIP របស់​លោក​អ្នក ប៉ុន្ដែ​ត្រូវ​បាន​កំណត់​ទិស​ដៅ​ជា​ថ្មី​ទៅ​រកURL មួយ​ផ្សេង​ទៀត​។',
	'texte_requetes_echouent' => '<b>នៅ​ពេល​ដែល​សំណួរ MySQL មិន​ដំណើរការ​ជា​លក្ខណៈ​ប្រព័ន្ធ និង​ដោយ​គ្មាន​ហេតុផល​ច្បាស់លាស់ វា​អាច​ដោយសារ​សំណុំ​ទិន្នន័យ​ផ្ទាល់​របស់​វា​នោះ​។</b><p> MySQL មាន​លក្ខណៈ​ជួសជុល​នូវ​តារាង​របស់​ខ្លួន​ទៅ​តាម​ការ​សំរេច​របស់​ខ្លួន នៅ​ពេល​ដែល​ពួក​វា​មានការ​ខូចខាត​ដោយ​ចៃដន្យ​។ លោក​អ្នក​អាច​ព្យាយាម​ធ្វើការ​ជួសជុល​បែប​នេះ នៅ​ក្នុង​ករណី​មានការ​ខូចខាត លោក​អ្នក​ត្រូវ​រក្សា​ច្បាប់​ថតចំលង​នៃ​ផ្ទាំង​បង្ហាញ ដែល​អាច​មាន​គន្លឹះ​មួយ​ចំនួន​ស្ដី​ពី​អ្វី​ដែល​ខុស​ប្រក្រតី​...</p><p> ប្រសិនបើ​បញ្ហា​ទាំងនោះ​មិន​អាច​ដោះស្រាយ​បាន សូម​ទាក់ទង​ទៅ​ម៉ាស៊ីន​កូន​របស់​លោក​អ្នក​។ host.</p>', # MODIF
	'texte_selection_langue_principale' => 'អ្នក អាចជ្រើសយក "ភាសាចំបង" ខាងក្រោម នៃសៃថ៍។ គ្មានន័យថា អ្នកអាច ត្រឹមសរសេរ អត្ថបទ ក្នុងភាសា បានជ្រើសយក,​ប៉ុន្តែ កំណត់<ul><li> ទំរង់លំនាំដើម នៃថ្ងៃខែឆ្នាំ លើសៃថ៍សាធារណះ </li>
 <li>លក្ខណះនៃឧបកររៀបពុម្ភអក្សរ ដែលនឹងត្រូវបានប្រើប្រាស់ ដោយ SPIP សំរាប់ បង្កើតអត្ថបទ;</li>
 <li> ភាសា ត្រូវបានប្រើប្រាស់ ក្រោមរូបភាព ជាសៃថ៍សាធារណះ</li>
 <li> ភាសាលំនាំដើម បានបង្ហាញចេញ ក្នុងផ្នែកឯកជន។</li></ul>',
	'texte_sous_titre' => 'ចំណងជើង​រង',
	'texte_statistiques_visites' => '(​របារ​ខ្មៅៈ​ថ្ងៃអាទិត្យ​/​កំណោង​ខ្មៅៈ កំរិត​មធ្យម',
	'texte_statut_attente_validation' => 'ការ​រង់ចាំ​ការ​ផ្ដល់​សុពលភាព',
	'texte_statut_publies' => 'បានបោះផ្សាយ លើអិនរើណែត',
	'texte_statut_refuses' => 'ត្រូវ​បាន​បដិសេធ',
	'texte_suppression_fichiers' => 'ប្រើប្រាស់​បញ្ជា​នេះ​ដើម្បី​លុប​ហ្វា​ល​ទាំងអស់​នៅ​ក្នុង​សំណុំ​ហ្វា​ល​លាក់ខ្លួន​របស់ SPIP។ វា​អនុញ្ញាត​ឱ្យ​លោក​អ្នក បង្ខំ​ការ​សម្រួល​ដំណើរការ​ឡើង​វិញ​នូវ​ទំព័រ​ទាំងអស់ ក្នុង​ចំ​ណោំ​អ្វី​ផ្សេងៗ​ទៀត នៅ​ក្នុង​ករណី​លោក​អ្នក​បាន​ធើ​ការ​កែប្រែ​សំខាន់ៗ​ទៅ​លើ​ក្រាហ្វិក ឬ​រចនាសម្ព័ន្ធ​របស់​វ៉ិ​ប​សាយ​។',
	'texte_sur_titre' => 'ចំណងជើងកំពូល',
	'texte_table_ok' => '៖ តារាង​នេះ​គឺ​ត្រឹមត្រូវ',
	'texte_tentative_recuperation' => 'ការ​ប៉ុនប៉ង​ជួសជុល',
	'texte_tenter_reparation' => 'ការ​ប៉ុនប៉ង​ជួសជុល​សំណុំ​ទិន្នន័យ',
	'texte_test_proxy' => 'ដើម្បី​ពិសោធ​តំណាង​នេះ សូម​បញ្ចូល​អាសយដ្ឋាន​វ៉ិ​ប​សាយ​ដែល​លោក​អ្នក​ត្រូវការ​ពិសោធន៍',
	'texte_titre_02' => 'ប្រធានបទៈ',
	'texte_titre_obligatoire' => '<b>Title</b> [ចាំបាច់]',
	'texte_travail_article' => 'បាន​ដំណើរការ​លើ​អត្ថបទ​នេះ @date_diff@ នាទី​ក្រោម​មក',
	'texte_travail_collaboratif' => 'ប្រសិនបើជា​រឿយៗ មាន​អ្នក​សរសេរ​កម្មវិធី​ច្រើន​អាច​ធ្វើការ​ងារ​លើ​អត្ថបទ​តែ​មួយ ប្រព័ន្ធ​អាច​កត់សំគាល់​ការងារ​ថ្មី​ជាងគេ «opened&raquo។ អត្ថបទ​ត្រូវ​រៀបចំ​ឱ្យ​មាន​របៀបរៀបរយ ដើម្បី​ជៀសវាង​ការ​កែប្រែ​រួម​គ្នា​ដែល​ធ្វើ​ឡើង​។ ជម្រើស​នេះ​ត្រូវ​បាន​បិទមុខ​ងារ​ដោយ​ក្រុមហ៊ុន​ផលិត ដើម្បី​ជៀស​វា​ពី​ការ​រំលឹក​មិន​ចាំបាច់​។ សារ​។', # MODIF
	'texte_vide' => 'ទទេ',
	'texte_vider_cache' => 'លុបសំអាត សតិភ្ជាប់',
	'titre_admin_tech' => 'តំហែទាំ បច្ចេកទេស',
	'titre_cadre_afficher_article' => 'បង្ហាញ អត្ថបទ៖',
	'titre_cadre_afficher_traductions' => 'បង្ហាញ ស្ថានភាពប្រែសំរួល សំរាប់ ភាសាខាងក្រោម ៖',
	'titre_cadre_ajouter_auteur' => 'បន្ថែម​អ្នក​សរសេរ​កម្មវិធី',
	'titre_cadre_interieur_rubrique' => 'នៅ​ក្នុង​ផ្នែក',
	'titre_cadre_numero_auteur' => 'អ្នក​សរសេរ​កម្មវិធី​លេខ',
	'titre_cadre_signature_obligatoire' => '<b>Signature</b> [ចាំបាច់]<br />',
	'titre_config_contenu_public' => 'លើ សៃថ៍សាធារណះ',
	'titre_config_fonctions' => 'ការកំណត់ទំរង់ សៃថ៍',
	'titre_configuration' => 'ការកំណត់ទំរង់ សៃថ៍',
	'titre_connexion_ldap' => 'ជម្រើស <b>Your LDAP បណ្ដាញ</b>',
	'titre_groupe_mots' => 'ក្រុម​ពាក្យ​គន្លឹះៈ',
	'titre_langue_article' => 'ភាសា​របស់​អត្ថបទ', # MODIF
	'titre_langue_rubrique' => 'ភាសា ក្នុងផ្នែក', # MODIF
	'titre_langue_trad_article' => 'ភាសា និង​ការ​បកប្រែ​អត្ថបទ',
	'titre_les_articles' => 'អត្ថបទ',
	'titre_naviguer_dans_le_site' => 'ត្រាច់ចរ ក្នុងសៃថ៍​...',
	'titre_nouvelle_rubrique' => 'ផ្នែក​ថ្មី',
	'titre_numero_rubrique' => 'លេខ​ផ្នែកៈ',
	'titre_page_articles_edit' => 'កែប្រែ ៖ @titre@',
	'titre_page_articles_page' => 'អត្ថបទ',
	'titre_page_articles_tous' => 'សៃថ៍ ទាំងមូល',
	'titre_page_calendrier' => 'ប្រតិទិន @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'ការកំណត់ទំរង់ សៃថ៍',
	'titre_page_delete_all' => 'ការ​លុប​ចោល​ទាំងស្រុង និង​មិន​អាច​បដិសេធ​វិញ​បាន',
	'titre_page_recherche' => 'លទ្ធផល​នៃ​ការ​ស្វែងរក @recherche@',
	'titre_page_statistiques_referers' => 'ស្ថិតិ (​ទំនាក់ទំនង​ចូល​)',
	'titre_page_upgrade' => 'ការ​កែ​លំអSPIP',
	'titre_publication_articles_post_dates' => 'ការ​ចុះ​ផ្សាយ​អត្ថបទ​ដែល​ចុះ​កាលបរិច្ឆេទ​យឺត',
	'titre_reparation' => 'ជួសជុល',
	'titre_suivi_petition' => 'ការ​តាមដាន​បដ្ឋនាលិខិត',
	'tls_ldap' => 'សុវត្ថិភាព​គាំទ្រ​ការ​ជញ្ជូន (Transport Layer Security)​ៈ',
	'trad_article_traduction' => 'គ្រប់កំណែ នៃអត្ថបទនេះ ៖',
	'trad_delier' => 'ឈប់​ភ្ជាប់​អត្ថបទ​នេះ​ទៅ​អត្ថបទ​បកប្រែ​របស់​វា​។', # MODIF
	'trad_lier' => 'អត្ថបទ​នេះ​គឺជា​អត្ថបទ​បកប្រែ​ដែល​មាន​លេខៈ',
	'trad_new' => 'សរសេរ​អត្ថបទ​បកប្រែ​ថ្មី​នៃ​អត្ថបទ​នេះ', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'កំហុស ៖ មិនគាំទ្រ កញ្ចប់អក្សរ @charset@។',

	// V
	'version' => 'កំណែ ៖',
];
